$AssetsAnimationsGen class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
mic
→ String
-
File path: assets/animations/mic.json
no setter
-
musicPlay
→ String
-
File path: assets/animations/music_play.json
no setter
-
noInternet
→ String
-
File path: assets/animations/no_internet.json
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<String>
-
List of all assets
no setter
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited