$AssetsLocalesGen class

Constructors

$AssetsLocalesGen()
const

Properties

ar String
File path: assets/locales/ar.json
no setter
en String
File path: assets/locales/en.json
no setter
fr String
File path: assets/locales/fr.json
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
List of all assets
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited