S class

Constructors

S()

Properties

adjust_speed String
Adjust speed
no setter
adjust_volume String
Adjust volume
no setter
audio_player String
Audio Player
no setter
cancel String
Cancel
no setter
done String
Done
no setter
hashCode int
The hash code for this object.
no setterinherited
playlist String
Playlist
no setter
recorder String
Recorder
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknownTrack String
Unknown Track
no setter
version String
1.3
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current S
no setter

Static Methods

load(Locale locale) Future<S>
maybeOf(BuildContext context) S?
of(BuildContext context) S

Constants

delegate → const AppLocalizationDelegate