$AssetsSvgGen class
Constructors
- $AssetsSvgGen()
-
const
Properties
- blueRightArrowIcon → String
-
File path: assets/svg/blue_right_arrow_icon.svg
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- intro1 → String
-
File path: assets/svg/intro1.svg
no setter
- intro1Bg → String
-
File path: assets/svg/intro_1_bg.svg
no setter
- intro2 → String
-
File path: assets/svg/intro2.svg
no setter
- intro3 → String
-
File path: assets/svg/intro3.svg
no setter
- intro4 → String
-
File path: assets/svg/intro4.svg
no setter
- login → $AssetsSvgLoginGen
-
Directory path: assets/svg/login
no setter
- rightWhiteArrow → String
-
File path: assets/svg/right_white_arrow.svg
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
String> -
List of all assets
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited