S class
Constructors
- S()
Properties
- adjust_speed → String
-
Adjust speedno setter - adjust_volume → String
-
Adjust volumeno setter - audio_player → String
-
Audio Playerno setter - cancel → String
-
Cancelno setter - done → String
-
Doneno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- playlist → String
-
Playlistno setter - recorder → String
-
Recorderno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknownTrack → String
-
Unknown Trackno setter - version → String
-
1.3no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
Locale locale) → Future< S> -
maybeOf(
BuildContext context) → S? -
of(
BuildContext context) → S
Constants
- delegate → const AppLocalizationDelegate